@@ -2,7 +2,7 @@
 
 from ocp_resources.constants import PROTOCOL_ERROR_EXCEPTION_DICT, TIMEOUT_4MINUTES
 from ocp_resources.resource import Resource
-from ocp_resources.utils import TimeoutSampler
+from timeout_sampler import TimeoutSampler
 
 
 class CDIConfig(Resource):
