@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 from ocp_resources.constants import PROTOCOL_ERROR_EXCEPTION_DICT, TIMEOUT_4MINUTES
 from ocp_resources.resource import NamespacedResource
-from ocp_resources.utils import TimeoutSampler, TimeoutWatch
+from timeout_sampler import TimeoutSampler, TimeoutWatch
 
 
 class Deployment(NamespacedResource):
