@@ -58,6 +58,4 @@ class Migration(NamespacedResource, MTV):
             )
 
             if self.cut_over:
-                self.res["spec"]["cutover"] = self.cut_over.strftime(
-                    format="%Y-%m-%dT%H:%M:%SZ"
-                )
+                self.res["spec"]["cutover"] = self.cut_over.strftime(format="%Y-%m-%dT%H:%M:%SZ")
