@@ -4,7 +4,7 @@ from kubernetes.dynamic.exceptions import ConflictError
 
 from ocp_resources.constants import TIMEOUT_4MINUTES
 from ocp_resources.resource import Resource
-from ocp_resources.utils import TimeoutSampler
+from timeout_sampler import TimeoutSampler
 
 SLEEP = 1
 
