@@ -1,8 +1,6 @@
 # -*- coding: utf-8 -*-
-from kubernetes.dynamic.exceptions import ResourceNotFoundError
 
 from ocp_resources.resource import Resource
-from ocp_resources.storage_profile import StorageProfile
 
 
 class StorageClass(Resource):
@@ -15,9 +13,6 @@ class StorageClass(Resource):
     class Types:
         """
         These are names of StorageClass instances when you run `oc get sc`
-
-        API:
-        https://kubernetes.io/docs/concepts/storage/storage-classes/
         """
 
         LOCAL_BLOCK = "local-block"
@@ -48,6 +43,7 @@ class StorageClass(Resource):
 
     class Annotations:
         IS_DEFAULT_CLASS = f"{Resource.ApiGroup.STORAGECLASS_KUBERNETES_IO}/is-default-class"
+        IS_DEFAULT_VIRT_CLASS = f"{Resource.ApiGroup.STORAGECLASS_KUBEVIRT_IO}/is-default-virt-class"
 
     class ReclaimPolicy:
         DELETE = "Delete"
@@ -106,14 +102,3 @@ class StorageClass(Resource):
                 self.res.update({"allowedTopologies": self.allowed_topologies})
             if self.mount_options:
                 self.res.update({"mountOptions": self.mount_options})
-
-    @property
-    def storage_profile(self):
-        try:
-            return StorageProfile(
-                client=self.client,
-                name=self.name,
-            )
-        except ResourceNotFoundError:
-            self.logger.error(f" storageProfile is not found for {self.name}  storageClass")
-            raise
