@@ -7,7 +7,7 @@ from ocp_resources.constants import (
     TIMEOUT_4MINUTES,
 )
 from ocp_resources.resource import NamespacedResource
-from ocp_resources.utils import TimeoutSampler
+from timeout_sampler import TimeoutSampler
 from ocp_resources.virtual_machine_instance import VirtualMachineInstance
 
 
